@@ -62,7 +62,10 @@ class ConstitutionEvidenceExtractor:
         self.repo_path = Path(repo_path)
 
     @beartype
-    @require(lambda repo_path: repo_path is None or repo_path.exists(), "Repository path must exist if provided")
+    @require(
+        lambda repo_path: repo_path is None or (isinstance(repo_path, Path) and repo_path.exists()),
+        "Repository path must exist if provided",
+    )
     @ensure(lambda result: isinstance(result, dict), "Must return dict")
     def extract_article_vii_evidence(self, repo_path: Path | None = None) -> dict[str, Any]:
         """
@@ -145,7 +148,7 @@ class ConstitutionEvidenceExtractor:
             )
         else:
             status = "FAIL"
-            issues = []
+            issues: list[str] = []
             if not depth_pass:
                 issues.append(
                     f"deep directory structure (max depth: {max_depth}, threshold: {self.MAX_DIRECTORY_DEPTH})"
@@ -167,7 +170,10 @@ class ConstitutionEvidenceExtractor:
         }
 
     @beartype
-    @require(lambda repo_path: repo_path is None or repo_path.exists(), "Repository path must exist if provided")
+    @require(
+        lambda repo_path: repo_path is None or (isinstance(repo_path, Path) and repo_path.exists()),
+        "Repository path must exist if provided",
+    )
     @ensure(lambda result: isinstance(result, dict), "Must return dict")
     def extract_article_viii_evidence(self, repo_path: Path | None = None) -> dict[str, Any]:
         """
@@ -252,7 +258,7 @@ class ConstitutionEvidenceExtractor:
             rationale = "No framework abstractions detected (direct library usage)"
         else:
             status = "FAIL"
-            issues = []
+            issues: list[str] = []
             if frameworks_detected:
                 issues.append(f"framework abstractions detected ({', '.join(frameworks_detected)})")
             if abstraction_layers > self.MAX_ABSTRACTION_LAYERS:
@@ -271,7 +277,10 @@ class ConstitutionEvidenceExtractor:
         }
 
     @beartype
-    @require(lambda repo_path: repo_path is None or repo_path.exists(), "Repository path must exist if provided")
+    @require(
+        lambda repo_path: repo_path is None or (isinstance(repo_path, Path) and repo_path.exists()),
+        "Repository path must exist if provided",
+    )
     @ensure(lambda result: isinstance(result, dict), "Must return dict")
     def extract_article_ix_evidence(self, repo_path: Path | None = None) -> dict[str, Any]:
         """
